from .supportive_functions import generate_female_name, generate_male_name, generate_surname_less


female_prefix = [
    "aða", "æl", "arn", "björn", "dís", "eið", "ey", "fríð", "gud", "gull", "gyð", "hild", "hjör",
    "ing", "líf", "run", "sif", "skjald", "skuld", "sól", "thor", "val", "víg", "ygg"
]

female_suffix = [
    "björg", "dóttir", "ey", "fey", "fríða", "gärd", "gyða", "hild", "hjör", "inga", "lína", "runa",
    "sigríð", "skjöld", "skuld", "sól", "thor", "vald", "ví", "vig", "ygg"
]

male_prefix = [
    "að", "al", "arn", "ask", "bað", "bjǫrn", "dǫrr", "eir", "ein", "fjǫr", "geir", "grim", "gunn",
    "hǫrð", "ing", "jarl", "kárr", "kol", "leifr", "mǫrk", "njal", "od", "ǫrn", "rauð", "skǫgr",
    "steinn", "tórr", "úlfr", "vald", "víð", "yng"
]

male_suffix = [
    "arr", "bjǫrn", "dall", "einarr", "fang", "geir", "grimr", "hǫrðr", "iarr", "jǫrn", "kell",
    "lárr", "mann", "njarð", "olfr", "ráð", "skell", "steinn", "thórr", "ulf", "valdr", "víðr",
    "yrn"
]

surname_prefix =  [
    "aeg", "aer", "arn", "as", "baer", "ber", "bjorn", "daeg", "dagr", "ein", "eir", "ey", "freyr",
    "gar", "geir", "grim", "haeg", "haer", "haf", "hald", "har", "hjor", "kjaer", "leifr", "mund",
    "raed", "raeg", "ran", "saer", "sig", "skjold", "staf", "stein", "svein", "thaeg", "thor", "tor",
    "ulfr", "vaeg", "vaer", "vald", "veig", "ver", "vid", "vigr", "vind", "yng"
]

surname_suffix = [
    "ard", "bjorn", "brand", "dal", "dottir", "drifa", "drot", "eidr", "fast", "fjord", "flod",
    "frej", "gard", "gils", "haugr", "heim", "hildr", "holt", "ing", "jord", "kjold", "lind", "magn",
    "nord", "rafn", "rak", "rik", "sif", "skar", "son", "stein", "stir", "thor", "tor", "ulf", "vald",
    "vang", "ve", "vig", "vin", "vir", "vor", "yng", "yv"
]

female = generate_female_name(female_prefix, female_suffix, min=0, max=1)
male = generate_male_name(male_prefix, male_suffix, min=0, max=1)
surname = generate_surname_less(surname_prefix, surname_suffix)


from .supportive_functions import generate_female_name, generate_male_name, generate_surname_less


male_prefix = [
    "aer", "ald", "an", "ar", "bar", "bor", "cal", "dal", "dan", "dur", "ed", "eld", "er", "fal",
    "fin", "gal", "gan", "gar", "had", "hal", "ian", "in", "kar", "kor", "lanc", "mar", "mer",
    "nor", "or", "rad", "ran", "ron", "sar", "sol", "tan", "thor", "tor", "ul", "val", "van",
    "vor", "wal", "war", "yor", "zar"
]

male_suffix = [
    "ald", "an", "ar", "ard", "bar", "dan", "dor", "dred", "dur", "fin", "gald", "gan", "gar",
    "hard", "horn", "ian", "ion", "lan", "mir", "nard", "or", "rad", "ran", "ric", "rin", "ron",
    "thor", "thorn", "und", "val", "var", "ward", "win", "wood", "wyn", "yar"
]

female_prefix = [
    "ad", "al", "an", "ar", "bel", "ca", "cel", "da", "di", "el", "en", "fa", "fay", "gal",
    "gi", "ha", "hel", "il", "in", "ja", "kel", "la", "le", "ma", "mi", "na", "ni", "ol",
    "pe", "qui", "ra", "re", "sa", "se", "ta", "thi", "va", "ve", "wil", "ya", "ze"
]

female_suffix = [
    "a", "ana", "ara", "beth", "cia", "da", "dea", "elle", "fa", "ga", "hilda", "ia", "iana",
    "ida", "ira", "la", "lia", "lina", "ma", "mia", "na", "nelle", "nia", "ra", "ria", "sa",
    "sia", "ta", "thea", "thia", "va", "via", "ya"
]

surname_prefix = [
    "ald", "arn", "bar", "ber", "brand", "carr", "cor", "dun", "eag", "eld", "fair", "gar", "gold",
    "han", "haw", "helm", "kings", "long", "oak", "rav", "red", "river", "rock", "silver", "stone",
    "thorn", "west", "white", "wind", "wynd", "yar", "zel", "al", "an", "ark", "ash", "ba",
    "bor", "be", "bel", "car", "cas", "cor", "dar", "de", "del", "di", "dor", "el", "er", "fal",
]

surname_suffix = [
    "bourne", "bridge", "brook", "castle", "field", "ford", "ham", "hurst", "lake", "ley", "mead",
    "mill", "shire", "stead", "stone", "ton", "view", "wall", "ward", "water", "well", "wick", "worth",
    "bay", "crest", "croft", "dale", "gate", "glen", "haven", "hill", "holme", "isle", "keep", "mere",
    "moor", "peak", "pool", "reach", "rise", "shade", "slope", "thorpe", "vale", "village", "weir", "wood",
    "yard", "zeal"
]

female = generate_female_name(female_prefix, female_suffix)
male = generate_male_name(male_prefix, male_suffix)
surname = generate_surname_less(surname_prefix, surname_suffix)



from . import dwarven, elven, giant, halfling, orc, human_steampunk, human_modern, human_medieval, human_greek, human_norsemen, human_arab, human_oriental, human_tolkien, human_jordan, human_erikson, human_rowling, human_sapkowski
from random import choice

def generate_name(gender=choice(['female', 'male']), style='modern'):
    if gender.lower() == 'male':
        match style:
            case 'elven':
                name = elven.male
            case 'dwarven':
                name = dwarven.male
            case 'giant':
                name = giant.male
            case 'halfling':
                name = halfling.male
            case 'orc':
                name = orc.male
            case 'modern':
                name = human_modern.male
            case 'greek':
                name = human_greek.male
            case 'norsemen':
                name = human_norsemen.male
            case 'arab':
                name = human_arab.male
            case 'oriental':
                name = human_oriental.male
            case 'steampunk':
                name = human_steampunk.male
            case 'medieval':
                name = human_medieval.male
            case 'tolkien':
                name = human_tolkien.male
            case 'jordan':
                name = human_jordan.male
            case 'erikson':
                name = human_erikson.male
            case 'rowling':
                name = human_rowling.male
            case 'sapkowski':
                name = human_sapkowski.male
    elif gender.lower() == 'female':
        match style:
            case 'elven':
                name = elven.female
            case 'dwarven':
                name = dwarven.female
            case 'giant':
                name = giant.female
            case 'halfling':
                name = halfling.female
            case 'orc':
                name = orc.female
            case 'modern':
                name = human_modern.female
            case 'greek':
                name = human_greek.female
            case 'norsemen':
                name = human_norsemen.female
            case 'arab':
                name = human_arab.female
            case 'oriental':
                name = human_oriental.female
            case 'steampunk':
                name = human_steampunk.female
            case 'medieval':
                name = human_medieval.female
            case 'tolkien':
                name = human_tolkien.female
            case 'jordan':
                name = human_jordan.female
            case 'erikson':
                name = human_erikson.female
            case 'rowling':
                name = human_rowling.female
            case 'sapkowski':
                name = human_sapkowski.female

    else:
        raise ValueError("Invalid gender specified. Please choose 'male' or 'female'.")

    if style.lower() == 'elven':
        surname = elven.surname
    elif style.lower() == 'dwarven':
        surname = dwarven.surname
    elif style.lower() == 'giant':
        surname = giant.surname
    elif style.lower() == 'halfling':
        surname = halfling.surname
    elif style.lower() == 'orc':
        surname = orc.surname
    elif style.lower() == 'modern':
        surname = human_modern.surname
    elif style.lower() == 'greek':
        surname = human_greek.surname
    elif style.lower() == 'norsemen':
        surname = human_norsemen.surname
    elif style.lower() == 'arab':
        surname = human_arab.surname
    elif style.lower() == 'oriental':
        surname = human_oriental.surname
    elif style.lower() == 'steampunk':
        surname = human_steampunk.surname
    elif style.lower() == 'medieval':
        surname = human_medieval.surname
    elif style.lower() == 'tolkien':
        surname = human_tolkien.surname
    elif style.lower() == 'jordan':
        surname = human_jordan.surname
    elif style.lower() == 'erikson':
        surname = human_erikson.surname
    elif style.lower() == 'rowling':
        surname = human_rowling.surname
    elif style.lower() == 'sapkowski':
        surname = human_sapkowski.surname
    else:
        raise ValueError("Invalid style specified. Please choose 'elven', 'dwarven', 'giant', 'halfling', 'orc', 'modern', 'greek', 'norsemen', 'arab', 'oriental', 'steampunk', 'medieval', 'tolkien', 'jordan', 'eriskon', 'rowling', or 'sapkowski'.")

    return f"{name} {surname}"


if __name__ == '__main__':
    name = generate_name()
    print(name)
